.. absfuyu documentation master file, created by
   sphinx-quickstart on Sun Dec 18 15:34:19 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to absfuyu's documentation!
===================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   info
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
